Glot
====
Go-Smart Glossia Simulation Architecture
----------------------------------------

**Primary authors** : [NUMA Engineering Services Ltd](http://www.numa.ie) (NUMA), Dundalk, Ireland

**Project website** : http://www.gosmart-project.eu/

This project is co-funded by: European Commission under grant agreement no. 600641.

This tool provides CLI tools for managing or interacting with Glossia tools via WAMP.

Dependencies
------------

glot has the following dependencies:

* Python3
   * aiohttp
   * Click
   * gitpython
   * tabulate
   * colorama
   * setuptools
* pip3 (for one-line installation)


Documentation
-------------

Documentation for this component is available at https://go-smart.github.io/glot

Quick Installation
------------------

See the documentation for fuller details. In summary, installation is as standard:

    python3 setup.py install
